@@ -48,7 +48,6 @@ PLATFORM = platform.system().lower()
 PYTHON_PATH = '/usr/bin/python'
 
 
-
 def try_except(tries=0, interval=1):
     def decorate(func):
         import functools
@@ -116,6 +115,12 @@ def init_log():
 
     @try_except()
     def set_options(*args, **kwargs):
+        '''
+        log.set_options(filename='/tmp/xxx.log', maxBytes=1024*1024, backupCount=3, level=logging.DEBUG,isLogConsole=True)
+        :param args:
+        :param kwargs:
+        :return:
+        '''
         filename = client_log_filename
         maxBytes = 100 * 1024 * 1024
         backupCount = 3
@@ -994,6 +999,24 @@ class ZbxCommon(object):
             # return ips
 
     def render(self, tpl_str, *args, **kwargs):
+        '''
+        example:
+        tpl=\'\'\'
+        <dl>
+            {% for key, value in d.items() %}
+            <dt>{{ key }}</dt>
+            <dd>{{ value }}</dd>
+            {% endfor %}
+        </dl>
+        \'\'\'
+        d={'key1':'value1','key2':'value2'}
+        print(cli.render(tpl,d=d))
+        print(cli.render(tpl,globals()))
+        :param tpl_str :
+        :param args:
+        :param kwargs:
+        :return:
+        '''
         from jinja2 import Environment
         tpl = Environment().from_string(tpl_str)
         return tpl.render(*args, **kwargs)
@@ -1050,6 +1073,10 @@ class ZbxCommon(object):
         return packages
 
     def get_mysql_connection(self, dsn_str):
+        '''
+        :param dsn_str='mysql://root:root@localhost:3306/ferry':
+        :return:
+        '''
         import dsnparse
         dsn = dsnparse.parse(dsn_str)
         import pymysql
@@ -1064,6 +1091,12 @@ class ZbxCommon(object):
         return connection
 
     def mysql_query(self, connection, sql, *args):
+        '''
+        :param connection=cli.get_mysql_connection('mysql://root:root@localhost:3306/ferry'):
+        :param sql select * from user where id in(?):
+        :param args 1,2,3
+        :return:
+        '''
         with connection.cursor() as cursor:
             sql = str(sql).strip()
             if re.match(r'select|show', sql, re.IGNORECASE):
@@ -1295,6 +1328,25 @@ class ZbxCommon(object):
             data = [data]
         return data
 
+    # parse table text with header and spliter  to list
+    def parse_text_to_list(self, text, regex_spliter='\t+', header=True):
+        text=text.strip()
+        lines = text.splitlines()
+        if header:
+            header = re.split(regex_spliter, lines[0])
+            lines = lines[1:]
+        else:
+            header = []
+        data = []
+        for line in lines:
+            line = line.strip()
+            if line != '':
+                row = re.split(regex_spliter, line)
+                if len(header) > 0:
+                    row = dict(zip(header, row))
+                data.append(row)
+        return data
+
     def dump_csv_string(self, data, date_format='%Y-%m-%d %H:%M:%S'):
         if isinstance(data, str):
             data = json.loads(data)
@@ -2188,7 +2240,6 @@ def handle_exception(exc_type, exc_value, exc_traceback):
 # sys.excepthook = handle_exception
 
 
-
 @cli.try_except()
 def __check_module():
     mds = cli.modules
