@@ -338,12 +338,47 @@ Exit:4->5
 
 # cli.dump_csv(data,'/Users/junqiang.zhang/Downloads/data1.csv')
 
-log.error("xxx")
+# log.error("xxx")
+#
+# log.set_options(filename='/tmp/xxx.log', maxBytes=1024*1024, backupCount=3, level=logging.DEBUG,isLogConsole=True)
+#
+# log.error("xxx")
+#
+#
+#
+# cli.http_get('http://www.baidu.com',headers={'User-Agent':'Mozilla/5.0 (Macintosh; Intel Mac OS X 10_14_6) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/77.0.3865.90 Safari/537.36'})
 
-log.set_options(filename='/tmp/xxx.log', maxBytes=1024*1024, backupCount=3, level=logging.DEBUG,isLogConsole=True)
-
-log.error("xxx")
+txt='''
+Email*						Mentor
+tianjiao.yang@shopee.com						xiaoyang.huang@shopee.com
+fa.chen@shopee.com						xigun.yan@shopee.com
+mingjun.shen@shopee.com						dongqi.zhou@shopee.com
+haibo.zhao@shopee.com						shengjun.li@shopee.com
+chao.yu@shopee.com						weimin.mei@shopee.com
+cong.zhou@shopee.com						tian.lan@shopee.com
+xiaohan.zhang@shopee.com						chang.yang@shopee.com
+rui.wangwr@shopee.com						gang.xiong@shopee.com
+xiangrong.peng@shopee.com						xia.he@shopee.com
+zhanghang@shopee.com						shiyao.peng@shopee.com
+lihui.wang@shopee.com						shangru.li@shopee.com
+jindong.pan@shopee.com						mingjie.wang@shopee.com
+xiangbin.guan@shopee.com						harry.chen@shopee.com
+jiawei.tian@shopee.com						shaofeng.lin@shopee.com
+zhangheng@shopee.com						wansheng.chen@shopee.com
+yidong.lan@shopee.com						shaofeng.lin@shopee.com
+jiaqi.zhu@shopee.com						yapeng.xiao@shopee.com
+tao.wen@shopee.com						yuanjing.lin@shopee.com
+zhihao.xu@shopee.com						junpeng.guo@shopee.com
+shubin.zhang@shopee.com						xing.wei@shopee.com
+linzijian@shopee.com						haibin.zhang@shopee.com
+zecheng.huang@shopee.com						shaofeng.hu@shopee.com
+'''
 
 
+data=cli.parse_text_to_list(txt)
 
-cli.http_get('http://www.baidu.com',headers={'User-Agent':'Mozilla/5.0 (Macintosh; Intel Mac OS X 10_14_6) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/77.0.3865.90 Safari/537.36'})
+print(data)
+
+# for row in data:
+#     sql=cli.gen_update_sql('user_tab',row,{'email':row['Email*']},['email'])
+#     print(sql)
